pub fn replace_memory_index(
store: &MemoryStore,
search: Option<&SearchEngine>,
mem: &Memory,
)Expand description
Delete-then-add re-index for an updated memory, with the same durable
pending-index marking as index_memory.
pub fn replace_memory_index(
store: &MemoryStore,
search: Option<&SearchEngine>,
mem: &Memory,
)Delete-then-add re-index for an updated memory, with the same durable
pending-index marking as index_memory.