pub struct ImaginePredictTool { /* private fields */ }Expand description
Imagination predict tool — predicts the outcome of a specific action.
Uses the bicameral world model to predict what would happen if a specific action is taken from a given state.
Implementations