pub struct WmMetaTool { /* private fields */ }Expand description
The fractal meta-tool — routes natural language or explicit route to tools.
Implementations
Sourceimpl WmMetaTool
impl WmMetaTool
pub fn new(registry: Arc<ToolRegistry>) -> Self
Sourcepub fn with_embedder(
registry: Arc<ToolRegistry>,
embedder: Box<dyn Embedder>,
) -> Self
pub fn with_embedder( registry: Arc<ToolRegistry>, embedder: Box<dyn Embedder>, ) -> Self
Create a new meta-tool with an embedding router.
If the embedder is a stub, the embedding router will be None and the
TF-IDF router is used as fallback.
Sourcepub fn with_embedder_and_shadow_stats(
registry: Arc<ToolRegistry>,
embedder: Box<dyn Embedder>,
shadow_stats: Arc<RwLock<ShadowModeStats>>,
) -> Self
pub fn with_embedder_and_shadow_stats( registry: Arc<ToolRegistry>, embedder: Box<dyn Embedder>, shadow_stats: Arc<RwLock<ShadowModeStats>>, ) -> Self
Create a new meta-tool with an embedding router and shared shadow stats.
Allows the caller to hold a reference to the shadow stats for observability and persistence.
Sourcepub fn with_router_shadow_stats_and_pipeline(
registry: Arc<ToolRegistry>,
embedder: Box<dyn Embedder>,
shadow_stats: Arc<RwLock<ShadowModeStats>>,
pipeline: Option<Arc<DispatchPipeline>>,
) -> Self
pub fn with_router_shadow_stats_and_pipeline( registry: Arc<ToolRegistry>, embedder: Box<dyn Embedder>, shadow_stats: Arc<RwLock<ShadowModeStats>>, pipeline: Option<Arc<DispatchPipeline>>, ) -> Self
Create a new meta-tool with an embedding router, shared shadow stats, and a dispatch pipeline for governance-gated inner dispatch.
Sourcepub const fn shadow_stats(&self) -> &Arc<RwLock<ShadowModeStats>> ⓘ
pub const fn shadow_stats(&self) -> &Arc<RwLock<ShadowModeStats>> ⓘ
Get a reference to the shadow mode stats for observability.
Sourcepub const fn embedding_router(&self) -> Option<&Arc<EmbeddingRouter>>
pub const fn embedding_router(&self) -> Option<&Arc<EmbeddingRouter>>
Get a reference to the embedding router, if present.